Struct color_parser::LUMA32
source · [−]Expand description
A color_parser in the luma color_parser space.
Fields
l: f32u: f32m: f32a: f32Trait Implementations
sourceimpl PartialOrd<LUMA32> for LUMA32
impl PartialOrd<LUMA32> for LUMA32
sourcefn partial_cmp(&self, other: &LUMA32) -> Option<Ordering>
fn partial_cmp(&self, other: &LUMA32) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for LUMA32
impl StructuralPartialEq for LUMA32