RGBColor

Struct RGBColor 

#[repr(C)]
pub struct RGBColor<T, A = T> { pub r: T, pub g: T, pub b: T, pub a: A, }
A color in the RGB Color Space.

Fields

r: T

The red channel of a rgb space color

g: T

The green channel of a rgb space color

b: T

The blue channel of a rgb space color

a: A

The alpha channel of a rgb space color

Implementations

Source

impl RGBColor<u8, ()>

pub const ALICEBLUE: RGBColor<u8, ()>

aliceblue: #F0F8FF

pub const ANTIQUEWHITE: RGBColor<u8, ()>

antiquewhite: #FAEBD7

pub const AQUA: RGBColor<u8, ()>

aqua: #00FFFF

pub const AQUAMARINE: RGBColor<u8, ()>

aquamarine: #7FFFD4

pub const AZURE: RGBColor<u8, ()>

azure: #F0FFFF

pub const BEIGE: RGBColor<u8, ()>

beige: #F5F5DC

pub const BISQUE: RGBColor<u8, ()>

bisque: #FFE4C4

pub const BLACK: RGBColor<u8, ()>

black: #000000

pub const BLANCHEDALMOND: RGBColor<u8, ()>

blanchedalmond: #FFEBCD

pub const BLUE: RGBColor<u8, ()>

blue: #0000FF

pub const BLUEVIOLET: RGBColor<u8, ()>

blueviolet: #8A2BE2

pub const BROWN: RGBColor<u8, ()>

brown: #A52A2A

pub const BURLYWOOD: RGBColor<u8, ()>

burlywood: #DEB887

pub const CADETBLUE: RGBColor<u8, ()>

cadetblue: #5F9EA0

pub const CHARTREUSE: RGBColor<u8, ()>

chartreuse: #7FFF00

pub const CHOCOLATE: RGBColor<u8, ()>

chocolate: #D2691E

pub const CORAL: RGBColor<u8, ()>

coral: #FF7F50

pub const CORNFLOWERBLUE: RGBColor<u8, ()>

cornflowerblue: #6495ED

pub const CORNSILK: RGBColor<u8, ()>

cornsilk: #FFF8DC

pub const CRIMSON: RGBColor<u8, ()>

crimson: #DC143C

pub const CYAN: RGBColor<u8, ()>

cyan: #00FFFF

pub const DARKBLUE: RGBColor<u8, ()>

darkblue: #00008B

pub const DARKCYAN: RGBColor<u8, ()>

darkcyan: #008B8B

pub const DARKGOLDENROD: RGBColor<u8, ()>

darkgoldenrod: #B8860B

pub const DARKGRAY: RGBColor<u8, ()>

darkgray: #A9A9A9

pub const DARKGREEN: RGBColor<u8, ()>

darkgreen: #006400

pub const DARKGREY: RGBColor<u8, ()>

darkgrey: #A9A9A9

pub const DARKKHAKI: RGBColor<u8, ()>

darkkhaki: #BDB76B

pub const DARKMAGENTA: RGBColor<u8, ()>

darkmagenta: #8B008B

pub const DARKOLIVEGREEN: RGBColor<u8, ()>

darkolivegreen: #556B2F

pub const DARKORANGE: RGBColor<u8, ()>

darkorange: #FF8C00

pub const DARKORCHID: RGBColor<u8, ()>

darkorchid: #9932CC

pub const DARKRED: RGBColor<u8, ()>

darkred: #8B0000

pub const DARKSALMON: RGBColor<u8, ()>

darksalmon: #E9967A

pub const DARKSEAGREEN: RGBColor<u8, ()>

darkseagreen: #8FBC8F

pub const DARKSLATEBLUE: RGBColor<u8, ()>

darkslateblue: #483D8B

pub const DARKSLATEGRAY: RGBColor<u8, ()>

darkslategray: #2F4F4F

pub const DARKSLATEGREY: RGBColor<u8, ()>

darkslategrey: #2F4F4F

pub const DARKTURQUOISE: RGBColor<u8, ()>

darkturquoise: #00CED1

pub const DARKVIOLET: RGBColor<u8, ()>

darkviolet: #9400D3

pub const DEEPPINK: RGBColor<u8, ()>

deeppink: #FF1493

pub const DEEPSKYBLUE: RGBColor<u8, ()>

deepskyblue: #00BFFF

pub const DIMGRAY: RGBColor<u8, ()>

dimgray: #696969

pub const DIMGREY: RGBColor<u8, ()>

dimgrey: #696969

pub const DODGERBLUE: RGBColor<u8, ()>

dodgerblue: #1E90FF

pub const FIREBRICK: RGBColor<u8, ()>

firebrick: #B22222

pub const FLORALWHITE: RGBColor<u8, ()>

floralwhite: #FFFAF0

pub const FORESTGREEN: RGBColor<u8, ()>

forestgreen: #228B22

pub const FUCHSIA: RGBColor<u8, ()>

fuchsia: #FF00FF

pub const GAINSBORO: RGBColor<u8, ()>

gainsboro: #DCDCDC

pub const GHOSTWHITE: RGBColor<u8, ()>

ghostwhite: #F8F8FF

pub const GOLDENROD: RGBColor<u8, ()>

goldenrod: #DAA520

pub const GOLD: RGBColor<u8, ()>

gold: #FFD700

pub const GRAY: RGBColor<u8, ()>

gray: #808080

pub const GREEN: RGBColor<u8, ()>

green: #008000

pub const GREENYELLOW: RGBColor<u8, ()>

greenyellow: #ADFF2F

pub const GREY: RGBColor<u8, ()>

grey: #808080

pub const HONEYDEW: RGBColor<u8, ()>

honeydew: #F0FFF0

pub const HOTPINK: RGBColor<u8, ()>

hotpink: #FF69B4

pub const INDIANRED: RGBColor<u8, ()>

indianred: #CD5C5C

pub const INDIGO: RGBColor<u8, ()>

indigo: #4B0082

pub const IVORY: RGBColor<u8, ()>

ivory: #FFFFF0

pub const KHAKI: RGBColor<u8, ()>

khaki: #F0E68C

pub const LAVENDERBLUSH: RGBColor<u8, ()>

lavenderblush: #FFF0F5

pub const LAVENDER: RGBColor<u8, ()>

lavender: #E6E6FA

pub const LAWNGREEN: RGBColor<u8, ()>

lawngreen: #7CFC00

pub const LEMONCHIFFON: RGBColor<u8, ()>

lemonchiffon: #FFFACD

pub const LIGHTBLUE: RGBColor<u8, ()>

lightblue: #ADD8E6

pub const LIGHTCORAL: RGBColor<u8, ()>

lightcoral: #F08080

pub const LIGHTCYAN: RGBColor<u8, ()>

lightcyan: #E0FFFF

pub const LIGHTGOLDENRODYELLOW: RGBColor<u8, ()>

lightgoldenrodyellow: #FAFAD2

pub const LIGHTGRAY: RGBColor<u8, ()>

lightgray: #D3D3D3

pub const LIGHTGREEN: RGBColor<u8, ()>

lightgreen: #90EE90

pub const LIGHTGREY: RGBColor<u8, ()>

lightgrey: #D3D3D3

pub const LIGHTPINK: RGBColor<u8, ()>

lightpink: #FFB6C1

pub const LIGHTSALMON: RGBColor<u8, ()>

lightsalmon: #FFA07A

pub const LIGHTSEAGREEN: RGBColor<u8, ()>

lightseagreen: #20B2AA

pub const LIGHTSKYBLUE: RGBColor<u8, ()>

lightskyblue: #87CEFA

pub const LIGHTSLATEGRAY: RGBColor<u8, ()>

lightslategray: #778899

pub const LIGHTSLATEGREY: RGBColor<u8, ()>

lightslategrey: #778899

pub const LIGHTSTEELBLUE: RGBColor<u8, ()>

lightsteelblue: #B0C4DE

pub const LIGHTYELLOW: RGBColor<u8, ()>

lightyellow: #FFFFE0

pub const LIME: RGBColor<u8, ()>

lime: #00FF00

pub const LIMEGREEN: RGBColor<u8, ()>

limegreen: #32CD32

pub const LINEN: RGBColor<u8, ()>

linen: #FAF0E6

pub const MAGENTA: RGBColor<u8, ()>

magenta: #FF00FF

pub const MAROON: RGBColor<u8, ()>

maroon: #800000

pub const MEDIUMAQUAMARINE: RGBColor<u8, ()>

mediumaquamarine: #66CDAA

pub const MEDIUMBLUE: RGBColor<u8, ()>

mediumblue: #0000CD

pub const MEDIUMORCHID: RGBColor<u8, ()>

mediumorchid: #BA55D3

pub const MEDIUMPURPLE: RGBColor<u8, ()>

mediumpurple: #9370DB

pub const MEDIUMSEAGREEN: RGBColor<u8, ()>

mediumseagreen: #3CB371

pub const MEDIUMSLATEBLUE: RGBColor<u8, ()>

mediumslateblue: #7B68EE

pub const MEDIUMSPRINGGREEN: RGBColor<u8, ()>

mediumspringgreen: #00FA9A

pub const MEDIUMTURQUOISE: RGBColor<u8, ()>

mediumturquoise: #48D1CC

pub const MEDIUMVIOLETRED: RGBColor<u8, ()>

mediumvioletred: #C71585

pub const MIDNIGHTBLUE: RGBColor<u8, ()>

midnightblue: #191970

pub const MINTCREAM: RGBColor<u8, ()>

mintcream: #F5FFFA

pub const MISTYROSE: RGBColor<u8, ()>

mistyrose: #FFE4E1

pub const MOCCASIN: RGBColor<u8, ()>

moccasin: #FFE4B5

pub const NAVAJOWHITE: RGBColor<u8, ()>

navajowhite: #FFDEAD

pub const NAVY: RGBColor<u8, ()>

navy: #000080

pub const OLDLACE: RGBColor<u8, ()>

oldlace: #FDF5E6

pub const OLIVE: RGBColor<u8, ()>

olive: #808000

pub const OLIVEDRAB: RGBColor<u8, ()>

olivedrab: #6B8E23

pub const ORANGE: RGBColor<u8, ()>

orange: #FFA500

pub const ORANGERED: RGBColor<u8, ()>

orangered: #FF4500

pub const ORCHID: RGBColor<u8, ()>

orchid: #DA70D6

pub const PALEGOLDENROD: RGBColor<u8, ()>

palegoldenrod: #EEE8AA

pub const PALEGREEN: RGBColor<u8, ()>

palegreen: #98FB98

pub const PALETURQUOISE: RGBColor<u8, ()>

paleturquoise: #AFEEEE

pub const PALEVIOLETRED: RGBColor<u8, ()>

palevioletred: #DB7093

pub const PAPAYAWHIP: RGBColor<u8, ()>

papayawhip: #FFEFD5

pub const PEACHPUFF: RGBColor<u8, ()>

peachpuff: #FFDAB9

pub const PERU: RGBColor<u8, ()>

peru: #CD853F

pub const PINK: RGBColor<u8, ()>

pink: #FFC0CB

pub const PLUM: RGBColor<u8, ()>

plum: #DDA0DD

pub const POWDERBLUE: RGBColor<u8, ()>

powderblue: #B0E0E6

pub const PURPLE: RGBColor<u8, ()>

purple: #800080

pub const REBECCAPURPLE: RGBColor<u8, ()>

rebeccapurple: #663399

pub const RED: RGBColor<u8, ()>

red: #FF0000

pub const ROSYBROWN: RGBColor<u8, ()>

rosybrown: #BC8F8F

pub const ROYALBLUE: RGBColor<u8, ()>

royalblue: #4169E1

pub const SADDLEBROWN: RGBColor<u8, ()>

saddlebrown: #8B4513

pub const SALMON: RGBColor<u8, ()>

salmon: #FA8072

pub const SANDYBROWN: RGBColor<u8, ()>

sandybrown: #F4A460

pub const SEAGREEN: RGBColor<u8, ()>

seagreen: #2E8B57

pub const SEASHELL: RGBColor<u8, ()>

seashell: #FFF5EE

pub const SIENNA: RGBColor<u8, ()>

sienna: #A0522D

pub const SILVER: RGBColor<u8, ()>

silver: #C0C0C0

pub const SKYBLUE: RGBColor<u8, ()>

skyblue: #87CEEB

pub const SLATEBLUE: RGBColor<u8, ()>

slateblue: #6A5ACD

pub const SLATEGRAY: RGBColor<u8, ()>

slategray: #708090

pub const SLATEGREY: RGBColor<u8, ()>

slategrey: #708090

pub const SNOW: RGBColor<u8, ()>

snow: #FFFAFA

pub const SPRINGGREEN: RGBColor<u8, ()>

springgreen: #00FF7F

pub const STEELBLUE: RGBColor<u8, ()>

steelblue: #4682B4

pub const TAN: RGBColor<u8, ()>

tan: #D2B48C

pub const TEAL: RGBColor<u8, ()>

teal: #008080

pub const THISTLE: RGBColor<u8, ()>

thistle: #D8BFD8

pub const TOMATO: RGBColor<u8, ()>

tomato: #FF6347

pub const TURQUOISE: RGBColor<u8, ()>

turquoise: #40E0D0

pub const VIOLET: RGBColor<u8, ()>

violet: #EE82EE

pub const WHEAT: RGBColor<u8, ()>

wheat: #F5DEB3

pub const WHITE: RGBColor<u8, ()>

white: #FFFFFF

pub const WHITESMOKE: RGBColor<u8, ()>

whitesmoke: #F5F5F5

pub const YELLOW: RGBColor<u8, ()>

yellow: #FFFF00

pub const YELLOWGREEN: RGBColor<u8, ()>

yellowgreen: #9ACD32

Source

impl RGBColor<u8, ()>

pub fn gray(value: u8) -> RGBColor<u8, ()>

Creates a new gray color from the given value.

pub fn new(r: u8, g: u8, b: u8) -> RGBColor<u8, ()>

Creates a new rgb color from the given values.

Source

impl RGBColor<u8>

pub fn gray(value: u8) -> RGBColor<u8>

Create RGBA8 from (u8, u8, u8) tuple.

pub fn new(r: u8, g: u8, b: u8, a: u8) -> RGBColor<u8>

Create RGBA8 from (u8, u8, u8, u8) tuple.

pub fn map_all<F>(&self, f: F) -> RGBColor<u8>
where F: Fn(u8) -> u8,

Map operator to all channels.

Source

impl RGBColor<f32>

pub fn as_rgb(&self) -> RGBColor<u8, ()>

Create RGBA32 from (u8, u8, u8) tuple.

pub fn as_rgba(&self) -> RGBColor<u8>

Create RGBA32 from (u8, u8, u8, u8) tuple.

Source

impl RGBColor<f32>

pub fn gray(value: f32) -> RGBColor<f32>

Create a new gray color in the RGB Color Space.

Arguments

Input values are automatically normalized.

The normalized RGBA32 range is:

  • gray: [0, 1]
Examples
let rgba32 = RGBA32::gray(0.5).with_alpha(0.5);
pub fn new(r: f32, g: f32, b: f32, a: f32) -> RGBColor<f32>

Create a new color in the RGB Color Space.

Arguments

Input values are automatically normalized.

The normalized RGBA32 range is:

  • r: [0, 1]
  • g: [0, 1]
  • b: [0, 1]
  • a: [0, 1]
Examples
let rgba32 = RGBA32::new(1.0, 0.0, 0.0, 1.0);
Source

impl RGBColor<f32>

pub fn normalized(&self) -> RGBColor<f32>

Normalize RGBA32 color to range [0.0, 1.0].

The normalized RGBA32 range is:

  • r: [0, 1]
  • g: [0, 1]
  • b: [0, 1]
  • a: [0, 1]
pub fn gamma_corrected(&self, gamma: f32) -> RGBColor<f32>

If γ >= 1 , it is a gamma expansion, and if γ < 1, it is a gamma compression.

pub fn map_all<F>(&self, f: F) -> RGBColor<f32>
where F: Fn(f32) -> f32,

If γ >= 1 , it is a gamma expansion, and if γ < 1, it is a gamma compression.

Source

impl<T, A> RGBColor<T, A>

pub fn with_red(self, r: T) -> RGBColor<T, A>

Build a new color with the given red channel.

pub fn with_green(self, g: T) -> RGBColor<T, A>

Build a new color with the given green channel.

pub fn with_blue(self, b: T) -> RGBColor<T, A>

Build a new color with the given blue channel.

pub fn with_alpha(self, a: A) -> RGBColor<T, A>

Build a new color with the given alpha channel.

pub fn map<F, G>(&self, color: F, alpha: G) -> RGBColor<T, A>
where F: Fn(T) -> T, G: Fn(A) -> A, T: Clone, A: Clone,

Map operator to r, g, b channels, without alpha channel.

pub fn map_color<F>(&self, f: F) -> RGBColor<T, A>
where F: Fn(T) -> T, T: Clone, A: Clone,

Map operator to r, g, b channels, without alpha channel.

pub fn map_alpha<F>(&self, f: F) -> RGBColor<T, A>
where F: Fn(A) -> A, T: Clone, A: Clone,

Map operator to alpha channel only.